carrot.backends — Carrot v0.10.5 documentation

### Navigation

- index
- modules |
- next |
- previous |
- Carrot v0.10.5 documentation »
- API Reference »

# carrot.backends

Working with Backends.

`carrot.backends.` `get_backend_cls`(backend=None)

  Get backend class by name.

  The backend string is the full path to a backend class, e.g.:

      "carrot.backends.pyamqplib.Backend"

  If the name does not include “`.`” (is not fully qualified), the alias table will be consulted.

### Navigation

- index
- modules |
- next |
- previous |
- Carrot v0.10.5 documentation »
- API Reference »